@@ -6,12 +6,24 @@ from ..core.datastructures import ImmutableDict
 from ..sparrow_distribute.constants import DistributeStatus
 
 
+class StorageRecordBusiType:
+    ''' 入库时, 单据类型 '''
+    REFUND = 'refund'  # 退款单小票
+    EXCHANGE = 'exchange'  # 换货单小票
+    DISTRIBUTE = 'distribute'  # 发货单小票
+
+
 class StoreNumberInfo(object):
     """ 仓库信息及对应发货单状态 """
     SERVICE_STORE_NUMBER = "B3"
     SERVICE_STORE_NAME = "B3仓库"
     SERVICE_DESK_NUMBER = "ZT"
     SERVICE_DESK_NAME = "自提点"
+    SERVICE_STOP_NUMBER = "STOP"
+    SERVICE_STOP_NAME = "滞留仓"
+    AFTERSALE_WH_NUMBER = "AFS"
+    AFTERSALE_WH_CODE = "AFS"
+    AFTERSALE_WH_NAME = "退换货仓"
 
     DISTRIBUTE_STATUS_STORE_INFO_MAP = {
         DistributeStatus.SERVICE_DESK: {
@@ -23,13 +35,41 @@ class StoreNumberInfo(object):
             'name': SERVICE_STORE_NAME,
             'number': SERVICE_STORE_NUMBER,
             'code': DistributeStatus.SERVICE_STORE
+        },
+        DistributeStatus.SERVICE_STOP: {
+            'name': SERVICE_STOP_NAME,
+            'number': SERVICE_STOP_NUMBER,
+            'code': DistributeStatus.SERVICE_STOP
         }
     }
 
-    STORE_NUMBER_TO_NAME_MAP = {d['number']: d['name'] for d in DISTRIBUTE_STATUS_STORE_INFO_MAP.values()}
-    STORE_NUMBER_TO_CODE_MAP = {d['number']: d['code'] for d in DISTRIBUTE_STATUS_STORE_INFO_MAP.values()}
-    STORE_CODE_TO_NAME_MAP = {d['code']: d['name'] for d in DISTRIBUTE_STATUS_STORE_INFO_MAP.values()}
-    STORE_CODE_TO_NUMBER_MAP = {d['code']: d['number'] for d in DISTRIBUTE_STATUS_STORE_INFO_MAP.values()}
+    STORE_INFO_MAP = {
+        SERVICE_STORE_NUMBER: {
+            'name': SERVICE_STORE_NAME,
+            'number': SERVICE_STORE_NUMBER,
+            'code': DistributeStatus.SERVICE_STORE
+        },
+        SERVICE_DESK_NUMBER: {
+            'name': SERVICE_DESK_NAME,
+            'number': SERVICE_DESK_NUMBER,
+            'code': DistributeStatus.SERVICE_DESK
+        },
+        SERVICE_STOP_NUMBER: {
+            'name': SERVICE_STOP_NAME,
+            'number': SERVICE_STOP_NUMBER,
+            'code': DistributeStatus.SERVICE_STOP
+        },
+        AFTERSALE_WH_NUMBER: {
+            'name': AFTERSALE_WH_NAME,
+            'number': AFTERSALE_WH_NUMBER,
+            'code': AFTERSALE_WH_CODE,
+        }
+    }
+
+    STORE_NUMBER_TO_NAME_MAP = {d['number']: d['name'] for d in STORE_INFO_MAP.values()}
+    STORE_NUMBER_TO_CODE_MAP = {d['number']: d['code'] for d in STORE_INFO_MAP.values()}
+    STORE_CODE_TO_NAME_MAP = {d['code']: d['name'] for d in STORE_INFO_MAP.values()}
+    STORE_CODE_TO_NUMBER_MAP = {d['code']: d['number'] for d in STORE_INFO_MAP.values()}
 
 
 class InventoryDetailResult(object):
