@@ -560,3 +560,60 @@ class UserOptDetail(BaseModelTimeAndDeleted):
 
     def __str__(self):
         return f'{self.opt_username}-{self.opt_displayname}-{self.event_code}-{self.event_day}-{self.shop_name}'
+
+
+class DistributelineEcard(BaseModelTimeAndDeleted):
+    # order_id (订单主键)
+    order_id = models.PositiveIntegerField('Order ID', blank=True, null=True)
+    # order_number (订单编码)
+    order_number = models.CharField('Order Number', max_length=36, blank=True)
+    # line_id(订单行id)
+    line_id = models.PositiveIntegerField('Line ID', blank=True, null=True)
+    # distribute_id(发货单id)
+    distribute_id = models.CharField('Distribute ID', max_length=40, blank=True, null=True)
+    # distribute_number(发货单号）
+    distribute_number = models.CharField("Distribute Number", max_length=40)
+    # distribute_line_id(发货单Line id)
+    distribute_line_id = models.CharField('Distribute Line ID', max_length=40, blank=True, null=True, db_index=True)
+    # E卡卡号
+    ecard_number = models.CharField("Ecard Number", max_length=40)
+
+
+class ExpressRelaBack(BaseModelTimeAndDeleted):
+    '''
+    发货单与运单关系历史表
+    被删除的关系表存在这里，以便查询发货单绑过的所有运单号
+    '''
+    # id(主键uuid)
+    id = models.CharField(max_length=100, primary_key=True, default=get_uuid4_hex, editable=False)
+    # distribute_id(新发货单id)
+    distribute_id = models.CharField('Distribute ID', max_length=40, default=get_uuid4_hex, db_index=True)
+    # distribute_number(新发货单id)
+    distribute_number = models.CharField('Distribute Number', max_length=40)
+    # order_id (订单主键)
+    order_id = models.PositiveIntegerField('Order ID', blank=True, null=True, db_index=True)
+    # order_number (订单编码)
+    order_number = models.CharField('Order Number', max_length=36, blank=True, null=True)
+    # newexpressorder_id(运单信息id)
+    newexpressorder_id = models.CharField(max_length=40, default=get_uuid4_hex, editable=False)
+    # if_main 是否主单（当发生合单时，将给主单与运单关联数据打上此标记，表示运单先由此发货单生成）
+    if_main = models.BooleanField("是否主单", default=True)
+    # 是否参与了合单
+    if_merge = models.BooleanField("是否合单", default=False)
+    # 运单号
+    shipping_number = models.CharField("快递单号/母单号", max_length=64, blank=True, null=True, db_index=True)
+    # 快递公司中文
+    express_name = models.CharField("快递供应商", max_length=20, blank=True, null=True)
+    # 快递公司编码
+    express_code = models.CharField("快递代码", max_length=16, blank=True, null=True)
+    # 账号名称
+    account = models.CharField("账号名称", max_length=20, blank=True, null=True, default="")
+    # 删除时间
+    deleted_time = models.DateTimeField("Date Deleted", blank=True, null=True)
+    # 删除关联的原因
+    deleted_reason = models.CharField("删除原因", max_length=20, blank=True, null=True)
+
+    class Meta:
+        app_label = 'sparrow_distribute'
+        ordering = ['-created_time']
+    
\ No newline at end of file
